@extends('voyager::master')

@section('page_title', 'Crear Combo')

@section('page_header')
    <h1 class="page-title">
        <i class="voyager-plus"></i>Crear Combo
    </h1>
@stop

@section('content')
    <div class="container">

        <!-- Mostrar mensajes de error -->
        @if ($errors->any())
            <div class="alert alert-danger">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif

        <form action="/admin/crear-combo" method="POST" enctype="multipart/form-data">
            @csrf

            <div class="panel panel-body">
                <!-- Información básica del producto -->
                <div class="form-group">
                    <label for="codigo">Código</label>
                    <input type="text" class="form-control" id="codigo" name="codigo" value="{{ old('codigo') }}">
                </div>

                <div class="form-group">
                    <label for="articulo">Artículo</label>
                    <input type="text" class="form-control" id="articulo" name="articulo" value="{{ old('articulo') }}">
                </div>

                <div class="form-group">
                    <label for="imagenes">Imágenes</label>
                    <input type="file" class="form-control" id="imagenes" name="imagenes[]" multiple>
                </div>


                <div class="form-group">
                    <label for="desc_fiscal">Descripción Fiscal</label>
                    <input type="text" class="form-control" id="desc_fiscal" name="desc_fiscal"
                        value="{{ old('desc_fiscal') }}">
                </div>

                <?php
                $productos = DB::table('products_excel')->get();
                $familias = DB::table('familia')->get();
                $categorias = DB::table('categories')->get();
                $rubros = DB::table('rubros')->get();
                ?>

                <div class="form-group">
                    <label for="categoria">Familia</label>

                    <select name="familia" class="form-control select2" id="familia_select">
                        <option value="">{{ __('Seleccione una familia') }}</option>
                        @foreach ($familias as $familia)
                            <option value="{{ $familia->id }}" {{ old('familia') == $familia->id ? 'selected' : '' }}>
                                {{ $familia->nombre }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="categoria">Categoría</label>
                    <select name="categoria" class="form-control select2" id="categoria_select" disabled>
                        <option value="">{{ __('Seleccione una categoría') }}</option>
                        @foreach ($categorias as $categoria)
                            <option value="{{ $categoria->id }}"
                                {{ old('categoria') == $categoria->id ? 'selected' : '' }}>
                                {{ $categoria->name }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="descuento_combo">Descuento por combo</label>
                    <input type="number" class="form-control" id="descuento_combo" name="descuento_combo"
                        value="{{ old('descuento_combo') }}">
                </div>

                <div class="form-group">
                    <label for="publicado">Publicado</label>
                    <select class="form-control" id="publicado" name="publicado">
                        <option value="1" {{ old('publicado') == 1 ? 'selected' : '' }}>Sí</option>
                        <option value="0" {{ old('publicado') == 0 ? 'selected' : '' }}>No</option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="rubro_id">Rubro ID</label>

                    <select name="rubro_id" class="form-control" id="rubro_select">
                        <option value="">{{ __('Seleccione un Rubro') }}</option>
                        @foreach ($rubros as $rubro)
                            <option value="{{ $rubro->id }}" {{ old('rubro_id') == $rubro->id ? 'selected' : '' }}>
                                {{ $rubro->nombre }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="destacado">Destacado</label>
                    <select class="form-control" id="destacado" name="destacado">
                        <option value="1" {{ old('destacado') == 1 ? 'selected' : '' }}>Sí</option>
                        <option value="0" {{ old('destacado') == 0 ? 'selected' : '' }}>No</option>
                    </select>
                </div>
            </div>

            <div class="panel panel-body">
                <!-- Productos del combo -->
                <div id="combo-products">
                    <h3>Productos del Combo</h3>
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Producto</th>
                                <th>Cantidad</th>
                                <th>Acciones</th>
                            </tr>
                        </thead>
                        <tbody id="combo-products-tbody">
                            <tr class="combo-product">
                                <td>
                                    <select class="form-control" name="combo_products[0][product_id]">
                                        @foreach ($productos as $producto)
                                            <option value="{{ $producto->id }}">{{ $producto->articulo }}</option>
                                        @endforeach
                                    </select>
                                </td>
                                <td>
                                    <input type="number" class="form-control" name="combo_products[0][cantidad]"
                                        min="1">
                                </td>
                                <td>
                                    <button type="button" class="btn btn-danger remove-combo-product">Eliminar</button>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>

            <button type="button" class="btn btn-secondary" id="add-combo-product">Añadir Producto al Combo</button>

            <button type="submit" class="btn btn-primary">Guardar Combo</button>
        </form>
    </div>
@endsection

@section('javascript')
    <script>
        document.getElementById('add-combo-product').addEventListener('click', function() {
            var comboProductsTbody = document.getElementById('combo-products-tbody');
            var newIndex = comboProductsTbody.getElementsByClassName('combo-product').length;
            var newComboProduct = `
            <tr class="combo-product">
                <td>
                    <select class="form-control" name="combo_products[${newIndex}][product_id]">
                        @foreach ($productos as $producto)
                            <option value="{{ $producto->id }}">{{ $producto->articulo }}</option>
                        @endforeach
                    </select>
                </td>
                <td>
                    <input type="number" class="form-control" name="combo_products[${newIndex}][cantidad]" min="1">
                </td>
                <td>
                    <button type="button" class="btn btn-danger remove-combo-product">Eliminar</button>
                </td>
            </tr>
            `;
            comboProductsTbody.insertAdjacentHTML('beforeend', newComboProduct);
        });

        document.addEventListener('click', function(event) {
            if (event.target && event.target.classList.contains('remove-combo-product')) {
                var row = event.target.closest('tr');
                row.parentNode.removeChild(row);
            }
        });

        $('#familia_select').on('change', function() {
            var familiaId = $(this).val();
            $('#categoria_select').prop('disabled', true);
            $('#categoria_select').html(
                '<option value="">{{ __('Cargando categorías...') }}</option>');

            if (familiaId) {
                $.ajax({
                    url: '/admin/categorias/get-by-familia',
                    type: 'GET',
                    data: {
                        familia_id: familiaId
                    },
                    success: function(data) {
                        var options =
                            '<option value="">{{ __('Seleccione una categoría') }}</option>';
                        data.forEach(function(categoria) {
                            options += '<option value="' + categoria.id + '">' +
                                categoria.name + '</option>';
                        });
                        $('#categoria_select').html(options);
                        $('#categoria_select').prop('disabled', false);
                    }
                });
            }
        });
    </script>
@endsection
