@extends('voyager::master')

@section('page_title', 'Editar Combo')

@section('page_header')
    <h1 class="page-title">
        <i class="voyager-edit"></i> Editar Combo
    </h1>
@stop

@section('content')
    <div class="container">

        <!-- Mostrar mensajes de error -->
        @if ($errors->any())
            <div class="alert alert-danger">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif

        <form action="/admin/combo/{{ $product->id }}" method="POST" enctype="multipart/form-data">
            @csrf

            <div class="panel panel-body">
                <!-- Información básica del producto -->
                <div class="form-group">
                    <label for="codigo">Código</label>
                    <input type="text" class="form-control" id="codigo" name="codigo"
                        value="{{ old('codigo', $product->codigo) }}">
                </div>

                <div class="form-group">
                    <label for="articulo">Artículo</label>
                    <input type="text" class="form-control" id="articulo" name="articulo"
                        value="{{ old('articulo', $product->articulo) }}">
                </div>

                <div class="form-group">
                    <label for="desc_fiscal">Descripción Fiscal</label>
                    <input type="text" class="form-control" id="desc_fiscal" name="desc_fiscal"
                        value="{{ old('desc_fiscal', $product->desc_fiscal) }}">
                </div>

                <div class="form-group">
                    <label for="imagenes">Imágenes</label>
                    <input type="file" class="form-control" id="imagenes" name="imagenes[]" multiple>
                    <div class="mt-3">
                        <?php
                        $imagenesProducto = $product->imagenes;
                        $imagenes = json_decode($imagenesProducto);
                        ?>
                        @foreach ($imagenes as $imagen)
                            <img src="{{ asset('storage/' . $imagen) }}" alt="Imagen del producto" width="100">
                            <label>
                                <input type="checkbox" name="delete_imagenes[]" value="{{ $imagen }}"> Eliminar
                            </label>
                        @endforeach
                    </div>
                </div>

                <?php
                $productos = DB::table('products_excel')->get();
                $familias = DB::table('familia')->get();
                $categorias = DB::table('categories')->get();
                $rubros = DB::table('rubros')->get();
                ?>

                <div class="form-group">
                    <label for="familia">Familia</label>
                    <select name="familia" class="form-control select2" id="familia_select">
                        <option value="">{{ __('Seleccione una familia') }}</option>
                        @foreach ($familias as $familia)
                            <option value="{{ $familia->id }}"
                                {{ old('familia', $product->familia) == $familia->id ? 'selected' : '' }}>
                                {{ $familia->nombre }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="categoria">Categoría</label>
                    <select name="categoria" class="form-control select2" id="categoria_select"
                        {{ old('familia', $product->familia) ? '' : 'disabled' }}>
                        <option value="">{{ __('Seleccione una categoría') }}</option>
                        @foreach ($categorias as $categoria)
                            <option value="{{ $categoria->id }}"
                                {{ old('categoria', $product->categoria) == $categoria->id ? 'selected' : '' }}>
                                {{ $categoria->name }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="descuento_combo">Descuento por combo</label>
                    <input type="number" class="form-control" id="descuento_combo" name="descuento_combo"
                        value="{{ old('descuento_combo', $product->descuento_combo) }}">
                </div>

                <div class="form-group">
                    <label for="publicado">Publicado</label>
                    <select class="form-control" id="publicado" name="publicado">
                        <option value="1" {{ old('publicado', $product->publicado) == 1 ? 'selected' : '' }}>Sí
                        </option>
                        <option value="0" {{ old('publicado', $product->publicado) == 0 ? 'selected' : '' }}>No
                        </option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="rubro_id">Rubro ID</label>
                    <select name="rubro_id" class="form-control" id="rubro_select">
                        <option value="">{{ __('Seleccione un Rubro') }}</option>
                        @foreach ($rubros as $rubro)
                            <option value="{{ $rubro->id }}"
                                {{ old('rubro_id', $product->rubro_id) == $rubro->id ? 'selected' : '' }}>
                                {{ $rubro->nombre }}
                            </option>
                        @endforeach
                    </select>
                </div>

                <div class="form-group">
                    <label for="destacado">Destacado</label>
                    <select class="form-control" id="destacado" name="destacado">
                        <option value="1" {{ old('destacado', $product->destacado) == 1 ? 'selected' : '' }}>Sí
                        </option>
                        <option value="0" {{ old('destacado', $product->destacado) == 0 ? 'selected' : '' }}>No
                        </option>
                    </select>
                </div>
            </div>

            <div class="panel panel-body">
                <!-- Productos del combo -->
                <div id="combo-products">
                    <h3>Productos del Combo</h3>
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Producto</th>
                                <th>Cantidad</th>
                                <th>Precio</th>
                                <th>Acciones</th>
                            </tr>
                        </thead>
                        <tbody id="combo-products-tbody">
                            @foreach ($product->products as $index => $comboProduct)
                                <tr class="combo-product">
                                    <td>
                                        <select class="form-control"
                                            name="combo_products[{{ $index }}][product_id]">
                                            @foreach ($productos as $producto)
                                                <option value="{{ $producto->id }}"
                                                    {{ $comboProduct->pivot->product_id == $producto->id ? 'selected' : '' }}>
                                                    {{ $producto->articulo }}
                                                </option>
                                            @endforeach
                                        </select>
                                    </td>
                                    <td>
                                        <input type="number" class="form-control"
                                            name="combo_products[{{ $index }}][cantidad]" min="1"
                                            value="{{ old('combo_products.' . $index . '.cantidad', $comboProduct->pivot->cantidad) }}">
                                    </td>
                                    <td>
                                        <button type="button" class="btn btn-danger remove-combo-product">Eliminar</button>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>

            <button type="button" class="btn btn-secondary" id="add-combo-product">Añadir Producto al Combo</button>

            <button type="submit" class="btn btn-primary">Actualizar Combo</button>
        </form>
    </div>
@endsection

@section('javascript')
    <script>
        document.getElementById('add-combo-product').addEventListener('click', function() {
            var comboProductsTbody = document.getElementById('combo-products-tbody');
            var newIndex = comboProductsTbody.getElementsByClassName('combo-product').length;
            var newComboProduct = `
            <tr class="combo-product">
                <td>
                    <select class="form-control" name="combo_products[${newIndex}][product_id]">
                        @foreach ($productos as $producto)
                            <option value="{{ $producto->id }}">{{ $producto->articulo }}</option>
                        @endforeach
                    </select>
                </td>
                <td>
                    <input type="number" class="form-control" name="combo_products[${newIndex}][cantidad]" min="1">
                </td>
                <td>
                    <button type="button" class="btn btn-danger remove-combo-product">Eliminar</button>
                </td>
            </tr>
            `;
            comboProductsTbody.insertAdjacentHTML('beforeend', newComboProduct);
        });

        document.addEventListener('click', function(event) {
            if (event.target && event.target.classList.contains('remove-combo-product')) {
                var row = event.target.closest('tr');
                row.parentNode.removeChild(row);
            }
        });

        document.getElementById('familia_select').onchange = function() {
            var familiaId = this.value;
            if (familiaId) {
                $.ajax({
                    url: '/admin/categorias/get-by-familia',
                    type: 'GET',
                    data: {
                        familia_id: familiaId
                    },
                    success: function(response) {
                        $('#categoria_select').prop('disabled', false).html(
                            '<option value="">{{ __('Seleccione una categoría') }}</option>');
                        $.each(response, function(key, value) {
                            $('#categoria_select').append('<option value="' + value.id + '">' +
                                value.name + '</option>');
                        });
                    }
                });
            } else {
                $('#categoria_select').prop('disabled', true).html(
                    '<option value="">{{ __('Seleccione una familia primero') }}</option>');
            }
        };
    </script>
@endsection
