@extends('voyager::master')

@section('page_title', 'Combos')

@section('page_header')
    <h1 class="page-title">
        <i class="voyager-list"></i> Combos
    </h1>
@stop

@section('content')
    <div class="page-content container-fluid">
        @include('voyager::alerts')
        <div class="row">
            <div class="col-md-12">
                <div>
                    <a href="/admin/crear-combo" class="btn btn-success btn-add-new">
                        <i class="voyager-plus"></i>
                        <span>Crear un Combo</span>
                    </a>
                </div>
                <div class="panel panel-bordered">
                    <div class="panel-body">
                        <form action="/admin/combos" method="GET" class="form-inline" style="margin-bottom: 15px;">
                            <div class="form-group">
                                <input type="text" name="search" class="form-control" placeholder="Buscar..."
                                    value="{{ $search }}">
                            </div>
                            <button type="submit" class="btn btn-primary">Buscar</button>
                        </form>
                        <div class="table-responsive">
                            <table id="dataTable" class="table table-hover">
                                <thead>
                                    <tr>
                                        <th>Código</th>
                                        <th>Artículo</th>
                                        <th>Imagen</th>
                                        <th>Familia</th>
                                        <th>Categoría</th>
                                        <th>Rubro</th>
                                        <th>Lista de Precios</th>
                                        <th>Stock Actual</th>
                                        <th>Fecha de Creación</th>
                                        <th>Publicado</th>
                                        <th>Combo</th>
                                        <th>Acciones</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($products as $product)
                                        <tr>
                                            <?php
                                            if ($product->imagenes) {
                                                $imagenesJson = $product->imagenes;
                                                $imagenes = json_decode($imagenesJson, true);
                                            } else {
                                                $imagenes = [null];
                                            }
                                            ?>
                                            <td>{{ $product->codigo }}</td>
                                            <td>{{ $product->articulo }}</td>
                                            <td><img src="/storage/{{ $imagenes[0] }}" alt="{{ $product->articulo }}"
                                                    width="50"></td>
                                            <td>
                                                <?php
                                                $familia = DB::table('familia')
                                                    ->where('id', $product->familia)
                                                    ->first();
                                                $familiaNombre = $familia ? $familia->nombre : '';
                                                ?>
                                                {{ $familiaNombre }}
                                            </td>
                                            <td>
                                                <?php
                                                $categoria = DB::table('categories')
                                                    ->where('id', $product->categoria)
                                                    ->first();
                                                $categoriaNombre = $categoria ? $categoria->name : '';
                                                ?>
                                                {{ $categoriaNombre }}
                                            </td>
                                            <td>
                                                <?php
                                                $rubro = DB::table('rubros')
                                                    ->where('id', $product->rubro_id)
                                                    ->first();
                                                $rubroNombre = $rubro ? $rubro->nombre : '';
                                                ?>
                                                {{ $rubroNombre }}
                                            </td>
                                            <td>{{ $product->lista_precios_1 }}</td>
                                            <td>{{ $product->stock_actual }}</td>
                                            <td>{{ $product->created_at->format('d/M/Y') }}</td>
                                            <td>
                                                <?php
                                                $publicado = null;
                                                if ($product->publicado === 1) {
                                                    $publicado = 'Publicado';
                                                } else {
                                                    $publicado = 'NO Publicado';
                                                }
                                                ?>
                                                {{ $publicado }}
                                            </td>
                                            <td>
                                                <?php
                                                $productosCombo = $product->products;
                                                ?>
                                                @foreach ($productosCombo as $producto)
                                                    {{ $producto->articulo }}
                                                @endforeach
                                            </td>
                                            <td class="no-sort no-click bread-actions">
                                                @can('delete', $product)
                                                    <a href="javascript:;" title="{{ __('voyager::generic.delete') }}"
                                                        class="btn btn-sm btn-danger pull-right delete"
                                                        data-id="{{ $product->id }}" id="delete-{{ $product->id }}">
                                                        <i class="voyager-trash"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.delete') }}</span>
                                                    </a>
                                                @endcan
                                                @can('edit', $product)
                                                    <a href="/admin/combos/{{ $product->id }}/edit"
                                                        title="{{ __('voyager::generic.edit') }}"
                                                        class="btn btn-sm btn-primary pull-right edit">
                                                        <i class="voyager-edit"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.edit') }}</span>
                                                    </a>
                                                @endcan
                                                @can('read', $product)
                                                    <a href="/admin/combos/{{ $product->id }}"
                                                        title="{{ __('voyager::generic.view') }}"
                                                        class="btn btn-sm btn-warning pull-right">
                                                        <i class="voyager-eye"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.view') }}</span>
                                                    </a>
                                                @endcan
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                        <div class="pull-left">
                            <div role="status" class="show-res" aria-live="polite">
                                {{ trans_choice('voyager::generic.showing_entries', $products->total(), [
                                    'from' => $products->firstItem(),
                                    'to' => $products->lastItem(),
                                    'all' => $products->total(),
                                ]) }}
                            </div>
                        </div>
                        <div class="pull-right">
                            {{ $products->appends(['search' => $search])->links('vendor.pagination.bootstrap-4') }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    {{-- Single delete modal --}}
    <div class="modal modal-danger fade" tabindex="-1" id="delete_modal" role="dialog">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal"
                        aria-label="{{ __('voyager::generic.close') }}"><span aria-hidden="true">&times;</span></button>
                    <h4 class="modal-title"><i class="voyager-trash"></i> {{ __('voyager::generic.delete_question') }}
                        {{ strtolower('producto') }}?</h4>
                </div>
                <div class="modal-footer">
                    <form action="#" id="delete_form" method="POST">
                        {{ method_field('DELETE') }}
                        {{ csrf_field() }}
                        <input type="submit" class="btn btn-danger pull-right delete-confirm"
                            value="{{ __('voyager::generic.delete_confirm') }}">
                    </form>
                    <button type="button" class="btn btn-default pull-right"
                        data-dismiss="modal">{{ __('voyager::generic.cancel') }}</button>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->
@stop

@section('javascript')
    <script>
        var deleteFormAction;
        $('td').on('click', '.delete', function(e) {
            $('#delete_form')[0].action = '/admin/products-excel/' + $(this).data('id');
            $('#delete_modal').modal('show');
        });
    </script>
@stop
