@php
    $edit = !is_null($dataTypeContent->getKey());
    $add = is_null($dataTypeContent->getKey());
@endphp

@extends('voyager::master')

@section('css')
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <!-- Incluye el CSS de Select2 -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
@stop

@section('page_title', __('voyager::generic.' . ($edit ? 'edit' : 'add')) . ' ' .
    $dataType->getTranslatedAttribute('display_name_singular'))

@section('page_header')
    <h1 class="page-title">
        <i class="{{ $dataType->icon }}"></i>
        Productos
    </h1>
    @include('voyager::multilingual.language-selector')
@stop

@section('content')
    <div class="page-content edit-add container-fluid">
        <div class="row">
            <div class="col-md-12">
                <div class="panel panel-bordered">
                    <!-- form start -->
                    <form role="form" class="form-edit-add"
                        action="{{ $edit ? route('voyager.' . $dataType->slug . '.update', $dataTypeContent->getKey()) : route('voyager.' . $dataType->slug . '.store') }}"
                        method="POST" enctype="multipart/form-data">
                        <!-- PUT Method if we are editing -->
                        @if ($edit)
                            {{ method_field('PUT') }}
                        @endif

                        <!-- CSRF TOKEN -->
                        {{ csrf_field() }}

                        <div class="panel-body">

                            @if (count($errors) > 0)
                                <div class="alert alert-danger">
                                    <ul>
                                        @foreach ($errors->all() as $error)
                                            <li>{{ $error }}</li>
                                        @endforeach
                                    </ul>
                                </div>
                            @endif

                            <!-- Adding / Editing -->
                            @php
                                $dataTypeRows = $dataType->{$edit ? 'editRows' : 'addRows'};
                            @endphp

                            @foreach ($dataTypeRows as $row)
                                <!-- GET THE DISPLAY OPTIONS -->
                                @php
                                    $display_options = $row->details->display ?? null;
                                    if ($dataTypeContent->{$row->field . '_' . ($edit ? 'edit' : 'add')}) {
                                        $dataTypeContent->{$row->field} =
                                            $dataTypeContent->{$row->field . '_' . ($edit ? 'edit' : 'add')};
                                    }
                                @endphp
                                @if (isset($row->details->legend) && isset($row->details->legend->text))
                                    <legend class="text-{{ $row->details->legend->align ?? 'center' }}"
                                        style="background-color: {{ $row->details->legend->bgcolor ?? '#f0f0f0' }};padding: 5px;">
                                        {{ $row->details->legend->text }}</legend>
                                @endif

                                <div class="form-group @if ($row->type == 'hidden') hidden @endif col-md-{{ $display_options->width ?? 12 }} {{ $errors->has($row->field) ? 'has-error' : '' }}"
                                    @if (isset($display_options->id)) {{ "id=$display_options->id" }} @endif>
                                    {{ $row->slugify }}
                                    <label class="control-label"
                                        for="name">{{ $row->getTranslatedAttribute('display_name') }}</label>
                                    @include('voyager::multilingual.input-hidden-bread-edit-add')

                                    <?php
                                    $productos = DB::table('products_excel')->get();
                                    $familias = DB::table('familia')->get();
                                    $categorias = DB::table('categories')->get();
                                    $rubros = DB::table('rubros')->get();
                                    ?>

                                    @if ($row->field === 'familia')
                                        <select name="familia" class="form-control select2" id="familia_select">
                                            <option value="">{{ __('Seleccione una familia') }}</option>
                                            @foreach ($familias as $familia)
                                                <option value="{{ $familia->id }}"
                                                    {{ $dataTypeContent->familia == $familia->id ? 'selected' : '' }}>
                                                    {{ $familia->nombre }}
                                                </option>
                                            @endforeach
                                        </select>
                                    @elseif ($row->field === 'categoria')
                                        <select name="categoria" class="form-control select2" id="categoria_select"
                                            disabled>
                                            <option value="">{{ __('Seleccione una categoría') }}</option>
                                            @foreach ($categorias as $categoria)
                                                <option value="{{ $categoria->id }}"
                                                    {{ $dataTypeContent->categoria == $categoria->id ? 'selected' : '' }}>
                                                    {{ $categoria->name }}
                                                </option>
                                            @endforeach
                                        </select>
                                    @elseif ($row->field === 'rubro_id')
                                        <select name="rubro_id" class="form-control select2" id="rubro_select"
                                            disabled>
                                            <option value="">{{ __('Seleccione un Rubro') }}</option>
                                            @foreach ($rubros as $rubro)
                                                <option value="{{ $rubro->id }}"
                                                    {{ $dataTypeContent->rubro_id == $rubro->id ? 'selected' : '' }}>
                                                    {{ $rubro->nombre }}
                                                </option>
                                            @endforeach
                                        </select>
                                    @elseif ($row->field === 'combo')
                                        @include('voyager::vendor.formfields.select-multiple', [
                                            'row' => $row,
                                            'dataType' => $dataType,
                                            'dataTypeContent' => $dataTypeContent,
                                            'options' => $row->details,
                                        ])
                                    @else
                                        @if ($add && isset($row->details->view_add))
                                            @include($row->details->view_add, [
                                                'row' => $row,
                                                'dataType' => $dataType,
                                                'dataTypeContent' => $dataTypeContent,
                                                'content' => $dataTypeContent->{$row->field},
                                                'view' => 'add',
                                                'options' => $row->details,
                                            ])
                                        @elseif ($edit && isset($row->details->view_edit))
                                            @include($row->details->view_edit, [
                                                'row' => $row,
                                                'dataType' => $dataType,
                                                'dataTypeContent' => $dataTypeContent,
                                                'content' => $dataTypeContent->{$row->field},
                                                'view' => 'edit',
                                                'options' => $row->details,
                                            ])
                                        @elseif (isset($row->details->view))
                                            @include($row->details->view, [
                                                'row' => $row,
                                                'dataType' => $dataType,
                                                'dataTypeContent' => $dataTypeContent,
                                                'content' => $dataTypeContent->{$row->field},
                                                'action' => $edit ? 'edit' : 'add',
                                                'view' => $edit ? 'edit' : 'add',
                                                'options' => $row->details,
                                            ])
                                        @elseif ($row->type == 'relationship')
                                            @include('voyager::formfields.relationship', [
                                                'options' => $row->details,
                                            ])
                                        @else
                                            {!! app('voyager')->formField($row, $dataType, $dataTypeContent) !!}
                                        @endif

                                        @foreach (app('voyager')->afterFormFields($row, $dataType, $dataTypeContent) as $after)
                                            {!! $after->handle($row, $dataType, $dataTypeContent) !!}
                                        @endforeach
                                        @if ($errors->has($row->field))
                                            @foreach ($errors->get($row->field) as $error)
                                                <span class="help-block">{{ $error }}</span>
                                            @endforeach
                                        @endif
                                    @endif
                                </div>
                            @endforeach

                        </div><!-- panel-body -->

                        <div class="panel-footer">
                        @section('submit-buttons')
                            <button type="submit" class="btn btn-primary save">{{ __('voyager::generic.save') }}</button>
                        @stop
                        @yield('submit-buttons')
                    </div>
                </form>

                <div style="display:none">
                    <input type="hidden" id="upload_url" value="{{ route('voyager.upload') }}">
                    <input type="hidden" id="upload_type_slug" value="{{ $dataType->slug }}">
                </div>
            </div>
        </div>
    </div>
</div>

<div class="modal fade modal-danger" id="confirm_delete_modal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h4 class="modal-title"><i class="voyager-warning"></i> {{ __('voyager::generic.are_you_sure') }}</h4>
            </div>
            <div class="modal-body">
                <h4>{{ __('voyager::generic.are_you_sure_delete') }} '<span class="confirm_delete_name"></span>'</h4>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-default"
                    data-dismiss="modal">{{ __('voyager::generic.cancel') }}</button>
                <button type="button" class="btn btn-danger"
                    id="confirm_delete">{{ __('voyager::generic.delete_confirm') }}</button>
            </div>
        </div>
    </div>
</div>
@stop

@section('javascript')
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    var params = {};
    var $file;

    function deleteHandler(tag, isMulti) {
        return function() {
            $file = $(this).siblings(tag);

            params = {
                slug: '{{ $dataType->slug }}',
                filename: $file.data('file-name'),
                id: $file.data('id'),
                field: $file.parent().data('field-name'),
                multi: isMulti,
                _token: '{{ csrf_token() }}'
            }

            $('.confirm_delete_name').text(params.filename);
            $('#confirm_delete_modal').modal('show');
        };
    }

    $('document').ready(function() {
        $('.toggleswitch').bootstrapToggle();

        //Init datepicker for date fields if data-datepicker attribute defined
        //or if browser does not handle date inputs
        $('.form-group input[type=date]').each(function(idx, elt) {
            if (elt.hasAttribute('data-datepicker')) {
                elt.type = 'text';
                $(elt).datetimepicker($(elt).data('datepicker'));
            } else if (elt.type != 'date') {
                elt.type = 'text';
                $(elt).datetimepicker({
                    format: 'L',
                    extraFormats: ['YYYY-MM-DD']
                }).datetimepicker($(elt).data('datepicker'));
            }
        });

        @if ($isModelTranslatable)
            $('.side-body').multilingual({
                "editing": true
            });
        @endif

        $('.side-body input[data-slug-origin]').each(function(i, el) {
            $(el).slugify();
        });

        $('.form-group').on('click', '.remove-multi-image', deleteHandler('img', true));
        $('.form-group').on('click', '.remove-single-image', deleteHandler('img', false));
        $('.form-group').on('click', '.remove-multi-file', deleteHandler('a', true));
        $('.form-group').on('click', '.remove-single-file', deleteHandler('a', false));

        $('#confirm_delete').on('click', function() {
            $.post('{{ route('voyager.' . $dataType->slug . '.media.remove') }}', params, function(
                response) {
                if (response &&
                    response.data &&
                    response.data.status &&
                    response.data.status == 200) {

                    toastr.success(response.data.message);
                    $file.parent().fadeOut(300, function() {
                        $(this).remove();
                    })
                } else {
                    toastr.error("Error removing file.");
                }
            });

            $('#confirm_delete_modal').modal('hide');
        });
        $('[data-toggle="tooltip"]').tooltip();

        // Initialize Select2 for combo field
        $('select[name="combo"]').select2();

        $('#familia_select').on('change', function() {
            var familiaId = $(this).val();
            $('#categoria_select').prop('disabled', true);
            $('#categoria_select').html(
                '<option value="">{{ __('Cargando categorías...') }}</option>');

            if (familiaId) {
                $.ajax({
                    url: '/admin/categorias/get-by-familia',
                    type: 'GET',
                    data: {
                        familia_id: familiaId
                    },
                    success: function(data) {
                        var options =
                            '<option value="">{{ __('Seleccione una categoría') }}</option>';
                        data.forEach(function(categoria) {
                            options += '<option value="' + categoria.id + '">' +
                                categoria.name + '</option>';
                        });
                        $('#categoria_select').html(options);
                        $('#categoria_select').prop('disabled', false);
                    }
                });
            }
        });
    });
</script>
@stop
