@extends('voyager::master')

@section('page_title', 'Usuarios')

@section('page_header')
    <div class="d-flex justify-between items-center" style="margin: 0px 20px;">
        <div class="d-flex header-title">
            <img src="{{voyager_asset('images/iconos/user.webp')}}" alt="">
            <h1 class="page-title">
                Usuarios
            </h1>
        </div>
        <div class="btn-group"
            style="display: flex; justify-content: center; gap: 5px; align-items: center; margin-right: 130px;">
            <div class="dropdown">
                <button class="btn btn-primary dropdown-toggle" style="margin: 0px !important;" type="button"
                    data-bs-toggle="dropdown" aria-expanded="false">
                    Acciones disponibles
                </button>
                <ul class="dropdown-menu" style="margin: 0px !important; background: #fff !important">
                    <li>
                        <a class="dropdown-item" href="/admin/users/create">
                            <img src="{{voyager_asset('images/iconos/mas.webp')}}" alt="">
                            Crear un nuevo usuario
                        </a>
                    </li>
                    <li>
                        <a class="dropdown-item" href="/admin/importacion-users">
                            <img src="{{voyager_asset('images/iconos/excel.webp')}}" alt="">
                            Exportar / Importar en excel
                        </a>
                    </li>
                </ul>
            </div>
        </div>
    </div>
@stop

@section('content')
    <div class="page-content container-fluid">
        @include('voyager::alerts')
        @if (session('success'))
            <div class="alert alert-success">
                {{ session('success') }}
            </div>
        @endif
        @if (session('error'))
            <div class="alert alert-danger">
                {{ session('error') }}
            </div>
        @endif
        <div class="row">
            <div class="col-md-12">
                <div class="panel panel-bordered">
                    <div class="panel-body">
                        <form action="/admin/usuarios" method="GET" class="form-inline" style="margin-bottom: 15px;">
                            <div class="form-group">
                                <input type="text" name="search" class="form-control"
                                    placeholder="Buscar por nombre, apellido o nombre de fantasía..."
                                    value="{{ $search }}">
                            </div>
                            <div class="form-group">
                                <select name="role" class="form-control">
                                    <option value="">Seleccionar rol</option>
                                    <option value="1">Administrador</option>
                                    <option value="2">Comprador</option>
                                    <option value="3">Vendedor</option>
                                </select>
                            </div>
                            <div class="form-group">
                                <select name="status" class="form-control">
                                    <option value="">Seleccionar estado</option>
                                    <option value="active" {{ $status == 'active' ? 'selected' : '' }}>Activo</option>
                                    <option value="inactive" {{ $status == 'inactive' ? 'selected' : '' }}>Inactivo</option>
                                </select>
                            </div>
                            <button type="submit" class="btn btn-primary">Buscar</button>
                        </form>
                        <div class="table-responsive">
                            <table id="dataTable" class="table table-hover">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>Apellido y nombre</th>
                                        <th>Cliente</th>
                                        <th>Email</th>
                                        <th>Tipo de acceso</th>
                                        <th>Nombre de fantasia</th>
                                        <th>Estado</th>
                                        {{-- <th>Acciones</th> --}}
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($users as $user)
                                        <tr>
                                            <td>{{ $user->id }}</td>
                                            <td>
                                                <a href="/admin/users/{{$user->id}}">
                                                    {{ $user->name }}
                                                </a>
                                            </td>
                                            <td>{{ $user->cliente }}</td>
                                            <td>{{ $user->email }}</td>
                                            <td>{{ $user->role->display_name ?? '' }}</td>
                                            <td>{{ $user->fantasia_name }}</td>
                                            <td>{{ $user->status == 'active' ? 'Activo' : 'Inactivo' }}</td>
                                            {{-- <td class="no-sort no-click bread-actions">
                                                @can('delete', $user)
                                                    <a href="javascript:;" title="{{ __('voyager::generic.delete') }}"
                                                        class="btn btn-sm btn-danger pull-right delete"
                                                        data-id="{{ $user->id }}" id="delete-{{ $user->id }}">
                                                        <i class="voyager-trash"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.delete') }}</span>
                                                    </a>
                                                @endcan
                                                @can('edit', $user)
                                                    <a href="/admin/users/{{ $user->id }}/edit"
                                                        title="{{ __('voyager::generic.edit') }}"
                                                        class="btn btn-sm btn-primary pull-right edit">
                                                        <i class="voyager-edit"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.edit') }}</span>
                                                    </a>
                                                @endcan
                                                @can('read', $user)
                                                    <a href="/admin/users/{{ $user->id }}"
                                                        title="{{ __('voyager::generic.view') }}"
                                                        class="btn btn-sm btn-warning pull-right">
                                                        <i class="voyager-eye"></i> <span
                                                            class="hidden-xs hidden-sm">{{ __('voyager::generic.view') }}</span>
                                                    </a>
                                                @endcan
                                            </td> --}}
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                        <div class="pull-left">
                            <div role="status" class="show-res" aria-live="polite">
                                {{ trans_choice('voyager::generic.showing_entries', $users->total(), [
                                    'from' => $users->firstItem(),
                                    'to' => $users->lastItem(),
                                    'all' => $users->total(),
                                ]) }}
                            </div>
                        </div>
                        <div class="pull-right">
                            {{ $users->appends(['search' => $search, 'role' => $role, 'status' => $status])->links('vendor.pagination.bootstrap-4') }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    {{-- Single delete modal --}}
    <div class="modal modal-danger fade" tabindex="-1" id="delete_modal" role="dialog">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal"
                        aria-label="{{ __('voyager::generic.close') }}"><span aria-hidden="true">&times;</span></button>
                    <h4 class="modal-title"><i class="voyager-trash"></i> {{ __('voyager::generic.delete_question') }}
                        {{ strtolower('usuario') }}?</h4>
                </div>
                <div class="modal-footer">
                    <form action="#" id="delete_form" method="POST">
                        {{ method_field('DELETE') }}
                        {{ csrf_field() }}
                        <input type="submit" class="btn btn-danger pull-right delete-confirm"
                            value="{{ __('voyager::generic.delete_confirm') }}">
                    </form>
                    <button type="button" class="btn btn-default pull-right"
                        data-dismiss="modal">{{ __('voyager::generic.cancel') }}</button>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->
@stop

@section('javascript')
    <script>
        var deleteFormAction;
        $('td').on('click', '.delete', function(e) {
            $('#delete_form')[0].action = '/admin/users/' + $(this).data('id');
            $('#delete_modal').modal('show');
        });
    </script>
@stop
